==> IntelOPA-FMGUI.windows-10.5.0.0.141.src.zip: IntelOPA-FMGUI-10.5.0.0/src/com/intel/stl/ui/configuration/ForwardingInfoProcessor.java <==
/**
 * Copyright (c) 2015, Intel Corporation
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Intel Corporation nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.intel.stl.ui.configuration;

import static com.intel.stl.ui.model.DeviceProperty.LINEAR_FDB_CAP;
import static com.intel.stl.ui.model.DeviceProperty.LINEAR_FDB_TOP;
import static com.intel.stl.ui.model.DeviceProperty.MULTICAST_FDB_CAP;
import static com.intel.stl.ui.model.DeviceProperty.MULTICAST_FDB_TOP;
import static com.intel.stl.ui.model.DeviceProperty.PORT_ADRR_RANGE_CONFIG;

import com.intel.stl.api.subnet.SwitchInfoBean;
import com.intel.stl.ui.common.STLConstants;
import com.intel.stl.ui.model.DevicePropertyCategory;

public class ForwardingInfoProcessor extends BaseCategoryProcessor {

    @Override
    public void process(ICategoryProcessorContext context,
            DevicePropertyCategory category) {
        SwitchInfoBean switchInfo = context.getSwitchInfo();
        if (switchInfo == null) {
            getEmptySwitchForwardingInfo(category);
            return;
        }
        addProperty(category, LINEAR_FDB_CAP, dec(switchInfo.getLinearFDBCap()));
        addProperty(category, LINEAR_FDB_TOP, dec(switchInfo.getLinearFDBTop()));
        addProperty(category, MULTICAST_FDB_CAP,
                dec(switchInfo.getMulticastFDBCap()));
        addProperty(category, MULTICAST_FDB_TOP,
                dec(switchInfo.getMulticastFDBTop()));
        String trueStr = STLConstants.K0385_TRUE.getValue();
        String falseStr = STLConstants.K0386_FALSE.getValue();
        String value = falseStr;
        if (switchInfo.isAddrRangeConfigSupported()) {
            value = trueStr;
        }
        addProperty(category, PORT_ADRR_RANGE_CONFIG, value);
    }

    private void getEmptySwitchForwardingInfo(DevicePropertyCategory category) {
        addProperty(category, LINEAR_FDB_CAP, "");
        addProperty(category, LINEAR_FDB_TOP, "");
        addProperty(category, MULTICAST_FDB_CAP, "");
        addProperty(category, MULTICAST_FDB_TOP, "");
        addProperty(category, PORT_ADRR_RANGE_CONFIG, "");
    }
}

==> IntelOPA-FMGUI.windows-10.7.0.0.145.src.zip: IntelOPA-FMGUI-10.7.0.0/src/com/intel/stl/ui/configuration/ForwardingInfoProcessor.java <==
/**
 * Copyright (c) 2015, Intel Corporation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Intel Corporation nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.intel.stl.ui.configuration;

import static com.intel.stl.ui.model.DeviceProperty.LINEAR_FDB_CAP;
import static com.intel.stl.ui.model.DeviceProperty.LINEAR_FDB_TOP;
import static com.intel.stl.ui.model.DeviceProperty.MULTICAST_FDB_CAP;
import static com.intel.stl.ui.model.DeviceProperty.MULTICAST_FDB_TOP;
import static com.intel.stl.ui.model.DeviceProperty.PORT_ADRR_RANGE_CONFIG;
import static com.intel.stl.ui.model.DeviceProperty.PORT_GROUP_FDB_CAP;

import com.intel.stl.api.subnet.SwitchInfoBean;
import com.intel.stl.ui.common.STLConstants;
import com.intel.stl.ui.model.DevicePropertyCategory;

public class ForwardingInfoProcessor extends BaseCategoryProcessor {

    @Override
    public void process(ICategoryProcessorContext context,
            DevicePropertyCategory category) {
        SwitchInfoBean switchInfo = context.getSwitchInfo();
        if (switchInfo == null) {
            getEmptySwitchForwardingInfo(category);
            return;
        }
        addProperty(category, LINEAR_FDB_CAP,
                dec(switchInfo.getLinearFDBCap()));
        addProperty(category, LINEAR_FDB_TOP,
                hex(switchInfo.getLinearFDBTop()));
        addProperty(category, MULTICAST_FDB_CAP,
                dec(switchInfo.getMulticastFDBCap()));
        addProperty(category, MULTICAST_FDB_TOP,
                hex(switchInfo.getMulticastFDBTop()));
        int cap = switchInfo.getPortGroupFDBCap();
        if (cap != 0) {
            addProperty(category, PORT_GROUP_FDB_CAP,
                    dec(switchInfo.getPortGroupFDBCap()));
        }
        String trueStr = STLConstants.K0385_TRUE.getValue();
        String falseStr = STLConstants.K0386_FALSE.getValue();
        String value = falseStr;
        if (switchInfo.isAddrRangeConfigSupported()) {
            value = trueStr;
        }
        addProperty(category, PORT_ADRR_RANGE_CONFIG, value);
    }

    private void getEmptySwitchForwardingInfo(DevicePropertyCategory category) {
        addProperty(category, LINEAR_FDB_CAP, "");
        addProperty(category, LINEAR_FDB_TOP, "");
        addProperty(category, MULTICAST_FDB_CAP, "");
        addProperty(category, MULTICAST_FDB_TOP, "");
        addProperty(category, PORT_GROUP_FDB_CAP, "");
        addProperty(category, PORT_ADRR_RANGE_CONFIG, "");
    }
}
